@@ -25,14 +25,16 @@ if [ ! -r etc/rndc.key -a ! -r /etc/rndc.conf ]; then
   chroot . /usr/sbin/rndc-confgen -a
 fi
 ( cd usr/lib ; rm -rf liblwres.so.1 )
-( cd usr/lib ; ln -sf liblwres.so.1.1.1 liblwres.so.1 )
-( cd usr/lib ; rm -rf libisc.so.7 )
-( cd usr/lib ; ln -sf libisc.so.7.0.1 libisc.so.7 )
+( cd usr/lib ; ln -sf liblwres.so.1.2.1 liblwres.so.1 )
+( cd usr/lib ; rm -rf libisc.so.9 )
+( cd usr/lib ; ln -sf libisc.so.9.1.4 libisc.so.9 )
+( cd usr/lib ; rm -rf libbind.so.0 )
+( cd usr/lib ; ln -sf libbind9.so.0.0.4 libbind.so.0 )
 ( cd usr/lib ; rm -rf libisccc.so.0 )
-( cd usr/lib ; ln -sf libisccc.so.0.1.0 libisccc.so.0 )
-( cd usr/lib ; rm -rf libdns.so.11 )
-( cd usr/lib ; ln -sf libdns.so.11.0.2 libdns.so.11 )
-( cd usr/lib ; rm -rf libisccfg.so.0 )
-( cd usr/lib ; ln -sf libisccfg.so.0.0.7 libisccfg.so.0 )
+( cd usr/lib ; ln -sf libisccc.so.0.2.1 libisccc.so.0 )
+( cd usr/lib ; rm -rf libdns.so.20 )
+( cd usr/lib ; ln -sf libdns.so.20.0.0 libdns.so.20 )
+( cd usr/lib ; rm -rf libisccfg.so.1 )
+( cd usr/lib ; ln -sf libisccfg.so.1.0.4 libisccfg.so.1 )
 ( cd usr/sbin ; rm -rf lwresd )
 ( cd usr/sbin ; ln -sf named lwresd )
