@@ -1,21 +1,21 @@
 #!/bin/sh
 #
-# Copyright (C) 2000, 2001  Internet Software Consortium.
+# Copyright (C) 2004  Internet Systems Consortium, Inc. ("ISC")
+# Copyright (C) 2000, 2001, 2003  Internet Software Consortium.
 #
 # Permission to use, copy, modify, and distribute this software for any
 # purpose with or without fee is hereby granted, provided that the above
 # copyright notice and this permission notice appear in all copies.
 #
-# THE SOFTWARE IS PROVIDED "AS IS" AND INTERNET SOFTWARE CONSORTIUM
-# DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL
-# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL
-# INTERNET SOFTWARE CONSORTIUM BE LIABLE FOR ANY SPECIAL, DIRECT,
-# INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
-# FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
-# NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
-# WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+# THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH
+# REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
+# AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT,
+# INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
+# LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
+# OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
+# PERFORMANCE OF THIS SOFTWARE.
 
-# $Id: isc-config.sh.in,v 1.10 2001/04/16 22:29:55 bwelling Exp $
+# $Id: isc-config.sh.in,v 1.10.12.3 2004/03/08 04:04:12 marka Exp $
 
 prefix=/usr
 exec_prefix=${prefix}
@@ -37,6 +37,7 @@ Libraries:
 	isccfg
 	dns
 	lwres
+	bind9
 EOF
 	exit $1
 }
@@ -68,7 +69,7 @@ while test $# -gt 0; do
 		echo_exec_prefix=true
 		;;
 	--version)
-		echo VERSION=9.2.3
+		echo VERSION=9.3.0
 		exit 0
 		;;
 	--cflags)
@@ -95,6 +96,12 @@ while test $# -gt 0; do
 	lwres)
 		liblwres=true;
 		;;
+	bind9)
+		libdns=true;
+		libisc=true;
+		libisccfg=true;
+		libbind9=true;
+		;;
 	*)
 		usage 1 1>&2
 	esac
@@ -119,8 +126,11 @@ if test x"$echo_libs" = x"true"; then
 	if test x"$liblwres" = x"true" ; then
 		libs="$libs -llwres"
 	fi
+	if test x"$libbind9" = x"true" ; then
+		libs="$libs -lbind9"
+	fi
 	if test x"$libdns" = x"true" ; then
-		libs="$libs -ldns -L/usr/lib -lcrypto"
+		libs="$libs -ldns  -lcrypto "
 	fi
 	if test x"$libisccfg" = x"true" ; then
 		libs="$libs -lisccfg"
